## LIF Tags

Tags extracted from Leica Image Format (LIF) imaging files. As well as the tags listed below, all available information is extracted from the XML-format metadata in the LIF header.

> Tag Name | Writable | Values / Notes
> --- | --- | ---
> TimeStampList | no |

(This document generated automatically by Image::ExifTool::BuildTagLookup)
Last revised Jun 22, 2021

<-- ExifTool Tag Names